==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ArchiwizacjaBazy.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.ArchiwizacjaRodzajOperacji;
import pl.topteam.dps.enums.RodzajBazyDanych;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ArchiwizacjaBazy extends GenericDPSObject {
    /**
     * ARCHIWIZACJA_BAZY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * ARCHIWIZACJA_BAZY.URL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String url;

    /**
     * ARCHIWIZACJA_BAZY.KOMPRESJA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean kompresja;

    /**
     * ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataPrzeprowadzenia;

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajBazyDanych rodzajBazyDanych;

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private ArchiwizacjaRodzajOperacji rodzajOperacji;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ARCHIWIZACJA_BAZY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ARCHIWIZACJA_BAZY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.URL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUrl() {
        return url;
    }

    /**
     * ARCHIWIZACJA_BAZY.URL
     *
     * @param url
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUrl(String url) {
        this.url = url == null ? null : url.trim();
    }

    /**
     * @return ARCHIWIZACJA_BAZY.KOMPRESJA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getKompresja() {
        return kompresja;
    }

    /**
     * ARCHIWIZACJA_BAZY.KOMPRESJA
     *
     * @param kompresja
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKompresja(Boolean kompresja) {
        this.kompresja = kompresja;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataPrzeprowadzenia() {
        return dataPrzeprowadzenia;
    }

    /**
     * ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     *
     * @param dataPrzeprowadzenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataPrzeprowadzenia(Date dataPrzeprowadzenia) {
        this.dataPrzeprowadzenia = dataPrzeprowadzenia;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajBazyDanych getRodzajBazyDanych() {
        return rodzajBazyDanych;
    }

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     *
     * @param rodzajBazyDanych
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajBazyDanych(RodzajBazyDanych rodzajBazyDanych) {
        this.rodzajBazyDanych = rodzajBazyDanych;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public ArchiwizacjaRodzajOperacji getRodzajOperacji() {
        return rodzajOperacji;
    }

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     *
     * @param rodzajOperacji
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajOperacji(ArchiwizacjaRodzajOperacji rodzajOperacji) {
        this.rodzajOperacji = rodzajOperacji;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ArchiwizacjaBazy other = (ArchiwizacjaBazy) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getUrl() == null ? other.getUrl() == null : this.getUrl().equals(other.getUrl()))
            && (this.getKompresja() == null ? other.getKompresja() == null : this.getKompresja().equals(other.getKompresja()))
            && (this.getDataPrzeprowadzenia() == null ? other.getDataPrzeprowadzenia() == null : this.getDataPrzeprowadzenia().equals(other.getDataPrzeprowadzenia()))
            && (this.getRodzajBazyDanych() == null ? other.getRodzajBazyDanych() == null : this.getRodzajBazyDanych().equals(other.getRodzajBazyDanych()))
            && (this.getRodzajOperacji() == null ? other.getRodzajOperacji() == null : this.getRodzajOperacji().equals(other.getRodzajOperacji()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getUrl() == null) ? 0 : getUrl().hashCode());
        result = prime * result + ((getKompresja() == null) ? 0 : getKompresja().hashCode());
        result = prime * result + ((getDataPrzeprowadzenia() == null) ? 0 : getDataPrzeprowadzenia().hashCode());
        result = prime * result + ((getRodzajBazyDanych() == null) ? 0 : getRodzajBazyDanych().hashCode());
        result = prime * result + ((getRodzajOperacji() == null) ? 0 : getRodzajOperacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", url=").append(url);
        sb.append(", kompresja=").append(kompresja);
        sb.append(", dataPrzeprowadzenia=").append(dataPrzeprowadzenia);
        sb.append(", rodzajBazyDanych=").append(rodzajBazyDanych);
        sb.append(", rodzajOperacji=").append(rodzajOperacji);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ArchiwizacjaBazy.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.ArchiwizacjaRodzajOperacji;
import pl.topteam.dps.enums.RodzajBazyDanych;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ArchiwizacjaBazy extends GenericDPSObject {
    /**
     * ARCHIWIZACJA_BAZY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * ARCHIWIZACJA_BAZY.URL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String url;

    /**
     * ARCHIWIZACJA_BAZY.KOMPRESJA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean kompresja;

    /**
     * ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataPrzeprowadzenia;

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajBazyDanych rodzajBazyDanych;

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private ArchiwizacjaRodzajOperacji rodzajOperacji;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ARCHIWIZACJA_BAZY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ARCHIWIZACJA_BAZY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ARCHIWIZACJA_BAZY.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.URL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUrl() {
        return url;
    }

    /**
     * ARCHIWIZACJA_BAZY.URL
     *
     * @param url
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUrl(String url) {
        this.url = url == null ? null : url.trim();
    }

    /**
     * @return ARCHIWIZACJA_BAZY.KOMPRESJA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getKompresja() {
        return kompresja;
    }

    /**
     * ARCHIWIZACJA_BAZY.KOMPRESJA
     *
     * @param kompresja
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKompresja(Boolean kompresja) {
        this.kompresja = kompresja;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataPrzeprowadzenia() {
        return dataPrzeprowadzenia;
    }

    /**
     * ARCHIWIZACJA_BAZY.DATA_PRZEPROWADZENIA
     *
     * @param dataPrzeprowadzenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataPrzeprowadzenia(Date dataPrzeprowadzenia) {
        this.dataPrzeprowadzenia = dataPrzeprowadzenia;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajBazyDanych getRodzajBazyDanych() {
        return rodzajBazyDanych;
    }

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_BAZY_DANYCH
     *
     * @param rodzajBazyDanych
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajBazyDanych(RodzajBazyDanych rodzajBazyDanych) {
        this.rodzajBazyDanych = rodzajBazyDanych;
    }

    /**
     * @return ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public ArchiwizacjaRodzajOperacji getRodzajOperacji() {
        return rodzajOperacji;
    }

    /**
     * ARCHIWIZACJA_BAZY.RODZAJ_OPERACJI
     *
     * @param rodzajOperacji
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajOperacji(ArchiwizacjaRodzajOperacji rodzajOperacji) {
        this.rodzajOperacji = rodzajOperacji;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ArchiwizacjaBazy other = (ArchiwizacjaBazy) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getUrl() == null ? other.getUrl() == null : this.getUrl().equals(other.getUrl()))
            && (this.getKompresja() == null ? other.getKompresja() == null : this.getKompresja().equals(other.getKompresja()))
            && (this.getDataPrzeprowadzenia() == null ? other.getDataPrzeprowadzenia() == null : this.getDataPrzeprowadzenia().equals(other.getDataPrzeprowadzenia()))
            && (this.getRodzajBazyDanych() == null ? other.getRodzajBazyDanych() == null : this.getRodzajBazyDanych().equals(other.getRodzajBazyDanych()))
            && (this.getRodzajOperacji() == null ? other.getRodzajOperacji() == null : this.getRodzajOperacji().equals(other.getRodzajOperacji()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getUrl() == null) ? 0 : getUrl().hashCode());
        result = prime * result + ((getKompresja() == null) ? 0 : getKompresja().hashCode());
        result = prime * result + ((getDataPrzeprowadzenia() == null) ? 0 : getDataPrzeprowadzenia().hashCode());
        result = prime * result + ((getRodzajBazyDanych() == null) ? 0 : getRodzajBazyDanych().hashCode());
        result = prime * result + ((getRodzajOperacji() == null) ? 0 : getRodzajOperacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", url=").append(url);
        sb.append(", kompresja=").append(kompresja);
        sb.append(", dataPrzeprowadzenia=").append(dataPrzeprowadzenia);
        sb.append(", rodzajBazyDanych=").append(rodzajBazyDanych);
        sb.append(", rodzajOperacji=").append(rodzajOperacji);
        sb.append("]");
        return sb.toString();
    }
}
